# Installation

## Stable release

To install wbib, run this command in your terminal:

```bash
$ pip install wbib
```

This is the preferred method to install wbib, as it will always install the most recent stable release.

## From sources

The sources for wbib can be downloaded from the Github repo.

You can either clone the public repository:

```bash
$ git clone git://github.com/lubianat/wbib
```

Or download the tarball:

```bash
$ curl -OJL https://github.com/lubianat/wbib/tarball/master
```

Once you have a copy of the source, you can install it with:

```bash
$ python setup.py install
```
